@@ -21,14 +21,12 @@
 #include "renderer.h"
 #include "ksudoku_logging.h"
 
-#include <QApplication>
 #include <QPainter>
 #include <QPixmap>
 #include <QSvgRenderer>
 
-#include <kdegames_version.h>
-#include <KgTheme>
-#include <KgThemeProvider>
+#include <KGameTheme>
+#include <KGameThemeProvider>
 
 #include "settings.h"
 
@@ -40,21 +38,18 @@ Renderer* Renderer::instance() {
 }
 	
 Renderer::Renderer() {
-	m_themeProvider = new KgThemeProvider(QByteArray()); // empty config key to disable internal config storage
+	m_themeProvider = new KGameThemeProvider(QByteArray()); // empty config key to disable internal config storage
 	m_renderer = new QSvgRenderer();
 	m_cache = new KImageCache(QStringLiteral("ksudoku-cache"), 3*1024);
 	m_mathdokuStyle = false;
 	
 	m_themeProvider->discoverThemes(
-#if KDEGAMES_VERSION < QT_VERSION_CHECK(7, 4, 0)
-	    "appdata",
-#endif
 	    QStringLiteral("themes"), // theme file location
 	    QStringLiteral("default") // default theme file name
 	);
 	const QByteArray themeIdentifier = Settings::theme().toUtf8();
-	KgThemeProvider *provider = themeProvider();
-	const QList<const KgTheme *> themes = provider->themes();
+	KGameThemeProvider *provider = themeProvider();
+	const QList<const KGameTheme *> themes = provider->themes();
 	for (auto* theme : themes) {
 		if (theme->identifier() == themeIdentifier) {
 		    provider->setCurrentTheme(theme);
@@ -62,7 +57,7 @@ Renderer::Renderer() {
 		}
 	}
 	loadTheme(provider->currentTheme());
-	QObject::connect(m_themeProvider, &KgThemeProvider::currentThemeChanged, [this](const KgTheme* theme) {
+	QObject::connect(m_themeProvider, &KGameThemeProvider::currentThemeChanged, [this](const KGameTheme* theme) {
 		loadTheme(theme);
 	});
 
@@ -74,12 +69,12 @@ Renderer::~Renderer() {
 	delete m_renderer;
 }
 
-KgThemeProvider * Renderer::themeProvider() const
+KGameThemeProvider * Renderer::themeProvider() const
 {
 	return m_themeProvider;
 }
 
-bool Renderer::loadTheme(const KgTheme* theme) {
+bool Renderer::loadTheme(const KGameTheme* theme) {
 	bool res = m_renderer->load(theme->graphicsPath());
 	qCDebug(KSudokuLog) << "loading" << theme->graphicsPath();
 	if(!res)
@@ -96,7 +91,7 @@ bool Renderer::loadTheme(const KgTheme* theme) {
 }
 
 void Renderer::fillNameHashes() {
-    m_borderNames = QVector<QString>();
+    m_borderNames = QList<QString>();
     m_borderNames << QStringLiteral("");
     m_borderNames << QStringLiteral("1");
     m_borderNames << QStringLiteral("2");
@@ -150,21 +145,17 @@ void Renderer::fillNameHashes() {
 QPixmap Renderer::renderBackground(const QSize& size) const {
 	if(!m_renderer->isValid() || size.isEmpty()) return QPixmap();
 
-	const qreal dpr = qApp->devicePixelRatio();
-	const QSize scaledSize = QSize(qRound(size.width() * dpr), qRound(size.height() * dpr));
-
 	QPixmap pix;
-    QString cacheName = QStringLiteral("background_%1x%2").arg(scaledSize.width()).arg(scaledSize.height());
+    QString cacheName = QStringLiteral("background_%1x%2").arg(size.width()).arg(size.height());
 	if(!m_cache->findPixmap(cacheName, &pix))
 	{
-		pix = QPixmap(scaledSize);
+		pix = QPixmap(size);
 		pix.fill(Qt::transparent);
         QPainter p(&pix);
         m_renderer->render(&p, QStringLiteral("background"));
 		p.end();
 		m_cache->insertPixmap(cacheName, pix);
 	}
-	pix.setDevicePixelRatio(dpr);
 	return pix;
 }
 
@@ -184,26 +175,23 @@ QPointF fromRectToRect(const QPointF& p, const QRectF& from, const QRectF& to) {
 	               (p.y()-from.top())*to.height()/from.height()+to.top());
 }
 
-QPixmap Renderer::renderSpecial(SpecialType type, qreal size) const {
+QPixmap Renderer::renderSpecial(SpecialType type, int size) const {
 	if(!m_renderer->isValid() || size == 0) return QPixmap();
 	
 	//only show the errors if the option has been set
 	if(!Settings::showErrors() && type == SpecialCellMistake ) type = SpecialCell;
 	
-	const qreal dpr = qApp->devicePixelRatio();
-	const qreal scaledSize = qRound(size * dpr);
-
-    QString cacheName = QStringLiteral("special_%1_%2").arg(m_specialNames[type]).arg(scaledSize);
+    QString cacheName = QStringLiteral("special_%1_%2").arg(m_specialNames[type]).arg(size);
 	QPixmap pix;
 	if(!m_cache->findPixmap(cacheName, &pix)) {
-		pix = QPixmap(scaledSize, scaledSize);
+		pix = QPixmap(size, size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
 		
 		// NOTE fix for Qt's QSvgRenderer size reporting bug
 		QRectF r(m_renderer->boundsOnElement(m_specialNames[type]));
 		QRectF from(r.adjusted(+0.5,+0.5,-0.5,-0.5));
-		QRectF to(QRectF(0,0,scaledSize,scaledSize));
+		QRectF to(QRectF(0,0,size,size));
 		r.setTopLeft(fromRectToRect(r.topLeft(), from, to));
 		r.setBottomRight(fromRectToRect(r.bottomRight(), from, to));
 		
@@ -212,11 +200,10 @@ QPixmap Renderer::renderSpecial(SpecialType type, qreal size) const {
 		m_cache->insertPixmap(cacheName, pix);
 	}
 
-	pix.setDevicePixelRatio(dpr);
 	return pix;
 }
 
-QPixmap Renderer::renderSymbol(int symbol, qreal size, int max, SymbolType type) const {
+QPixmap Renderer::renderSymbol(int symbol, int size, int max, SymbolType type) const {
 	if(!m_renderer->isValid() || size == 0) return QPixmap();
 
 	QString set;
@@ -226,13 +213,10 @@ QPixmap Renderer::renderSymbol(int symbol, qreal size, int max, SymbolType type)
         set = QStringLiteral("symbol25");
 	}
 
-	const qreal dpr = qApp->devicePixelRatio();
-	const int scaledSize = qRound(size * dpr);
-
-    QString cacheName = QStringLiteral("%1_%2_%3_%4").arg(set).arg(symbol).arg(scaledSize).arg(type);
+    QString cacheName = QStringLiteral("%1_%2_%3_%4").arg(set).arg(symbol).arg(size).arg(type);
 	QPixmap pix;
 	if(!m_cache->findPixmap(cacheName, &pix)) {
-		pix = QPixmap(scaledSize, scaledSize);
+		pix = QPixmap(size, size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
 		
@@ -265,16 +249,14 @@ QPixmap Renderer::renderSymbol(int symbol, qreal size, int max, SymbolType type)
 		m_cache->insertPixmap(cacheName, pix);
 	}
 
-	pix.setDevicePixelRatio(dpr);
 	return pix;
 }
 
 QPixmap Renderer::renderSymbolOn(QPixmap pixmap, int symbol, int color, int max, SymbolType type) const {
 	// We use a smaller size of symbol in Mathdoku and Killer
 	// Sudoku, to allow space for the cage labels.
-	const qreal dpr = pixmap.devicePixelRatio();
-	qreal size = m_mathdokuStyle ? (pixmap.width()+1)*0.75 : pixmap.width();
-	int offset = m_mathdokuStyle ? qRound((pixmap.width()+7)/8.0/dpr) : 0;
+	int size = m_mathdokuStyle ? (pixmap.width()+1)*3/4 : pixmap.width();
+	int offset = m_mathdokuStyle ? (pixmap.width()+7)/8 : 0;
 	QPixmap symbolPixmap = renderSymbol(symbol, size, max, type);
 	if(color) {
 		// TODO this does not work, need some other way, maybe hardcode color into NumberType
@@ -294,7 +276,7 @@ QPixmap Renderer::renderSymbolOn(QPixmap pixmap, int symbol, int color, int max,
 	}
 }
 
-QPixmap Renderer::renderMarker(int symbol, int range, qreal size) const {
+QPixmap Renderer::renderMarker(int symbol, int range, int size) const {
 	if(!m_renderer->isValid() || size == 0) return QPixmap();
 	
 	QString set;
@@ -314,14 +296,11 @@ QPixmap Renderer::renderMarker(int symbol, int range, qreal size) const {
 		range = 25;
 	}
 
-	const qreal dpr = qApp->devicePixelRatio();
-	const int scaledSize = qRound(size * dpr);
-
     QString groupName = QStringLiteral("markers%1").arg(range);
-    QString cacheName = QStringLiteral("%1_%2_%3").arg(groupName).arg(symbol).arg(scaledSize);
+    QString cacheName = QStringLiteral("%1_%2_%3").arg(groupName).arg(symbol).arg(size);
 	QPixmap pix;
 	if(!m_cache->findPixmap(cacheName, &pix)) {
-		pix = QPixmap(scaledSize, scaledSize);
+		pix = QPixmap(size, size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
 		
@@ -339,7 +318,6 @@ QPixmap Renderer::renderMarker(int symbol, int range, qreal size) const {
 		m_cache->insertPixmap(cacheName, pix);
 	}
 
-	pix.setDevicePixelRatio(dpr);
 	return pix;
 }
 
@@ -349,7 +327,7 @@ QPixmap Renderer::renderMarkerOn(QPixmap pixmap, int symbol, int range, int colo
 
 	// We use a smaller size of marker in Mathdoku and Killer
 	// Sudoku, to allow space for the cage labels.
-	qreal size = m_mathdokuStyle ? (pixmap.width()+1)*0.75 : pixmap.width();
+	int size = m_mathdokuStyle ? (pixmap.width()+1)*3/4 : pixmap.width();
 	QPixmap symbolPixmap = renderMarker(symbol, range, size);
 	if(color) {
 		QPainter p(&symbolPixmap);
@@ -363,8 +341,7 @@ QPixmap Renderer::renderMarkerOn(QPixmap pixmap, int symbol, int range, int colo
 	} else {
 		QPainter p(&pixmap);
 		// Offset the marker from 0,0 in Mathdoku and Killer Sudoku.
-		const qreal dpr = pixmap.devicePixelRatio();
-		int offset = m_mathdokuStyle ? qRound((size + 7.0)/8.0/dpr) : 0;
+		int offset = m_mathdokuStyle ? (size + 7)/8 : 0;
 		p.drawPixmap(offset, 2*offset, symbolPixmap);
 		p.end();
 		return pixmap;
@@ -374,9 +351,7 @@ QPixmap Renderer::renderMarkerOn(QPixmap pixmap, int symbol, int range, int colo
 QPixmap Renderer::renderCageLabelOn(QPixmap pixmap, const QString & cageLabel)
 {
 	// TODO - Do font setup once during resize? Put 0+-x/ in themes?
-	const qreal dpr = pixmap.devicePixelRatio();
-	const int size = qRound(pixmap.width()/dpr);
-
+	int size = pixmap.width();
 	QPainter p(&pixmap);
     p.setPen(QStringLiteral("white"));	// Text is white on a dark rectangle.
 	p.setBrush(Qt::SolidPattern);
@@ -402,23 +377,20 @@ QPixmap Renderer::renderCageLabelOn(QPixmap pixmap, const QString & cageLabel)
 	return pixmap;
 }
 
-QPixmap Renderer::renderBorder(int border, GroupTypes type, qreal size) const {
+QPixmap Renderer::renderBorder(int border, GroupTypes type, int size) const {
 	if(!m_renderer->isValid() || size == 0) return QPixmap();
 	
-	const qreal dpr = qApp->devicePixelRatio();
-	const int scaledSize = qRound(size * dpr);
-
-    QString cacheName = QStringLiteral("contour_%1_%2_%3").arg(m_borderTypes[type]).arg(m_borderNames[border]).arg(scaledSize);
+    QString cacheName = QStringLiteral("contour_%1_%2_%3").arg(m_borderTypes[type]).arg(m_borderNames[border]).arg(size);
 	QPixmap pix;
 	if(!m_cache->findPixmap(cacheName, &pix)) {
-		pix = QPixmap(scaledSize, scaledSize);
+		pix = QPixmap(size, size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
 		
 		// NOTE fix for Qt's QSvgRenderer size reporting bug
         QRectF r(m_renderer->boundsOnElement(QStringLiteral("%1_%2").arg(m_borderTypes[type]).arg(m_borderNames[border])));
 		QRectF from(r.adjusted(+0.5,+0.5,-0.5,-0.5));
-		QRectF to(QRectF(0,0,scaledSize,scaledSize));
+		QRectF to(QRectF(0,0,size,size));
 		r.setTopLeft(fromRectToRect(r.topLeft(), from, to));
 		r.setBottomRight(fromRectToRect(r.bottomRight(), from, to));
 		
@@ -427,7 +399,6 @@ QPixmap Renderer::renderBorder(int border, GroupTypes type, qreal size) const {
 		m_cache->insertPixmap(cacheName, pix);
 	}
 
-	pix.setDevicePixelRatio(dpr);
 	return pix;
 }
 
@@ -453,8 +424,6 @@ QPixmap Renderer::renderSpecial3D(SpecialType type, int size) const {
 		m_cache->insertPixmap(cacheName, pix);
 	}
 
-	const qreal dpr = qApp->devicePixelRatio();
-	pix.setDevicePixelRatio(dpr);
 	return pix;
 }
 
