@@ -22,7 +22,6 @@
 
 #include "ksudoku_logging.h"
 
-#include <QApplication>
 #include <QGraphicsPixmapItem>
 #include <QGraphicsSceneEvent>
 
@@ -45,13 +44,13 @@ class CellGraphicsItem : public QGraphicsPixmapItem {
 public:
 	CellGraphicsItem(QPoint pos, int id, View2DScene* scene);
 public:
-	void resize(qreal gridSize);
+	void resize(int gridSize);
 	QPoint pos() const { return m_pos; }
 	void showCursor(QGraphicsItem* cursor);
 	void setType(SpecialType type);
 	void setCageLabel (const QString &cageLabel);
 	
-	void setValues(const QVector<ColoredValue> &values);
+	void setValues(const QList<ColoredValue> &values);
 protected:
 	void hoverEnterEvent(QGraphicsSceneHoverEvent* event) override;
 	void mousePressEvent(QGraphicsSceneMouseEvent* event) override;
@@ -61,10 +60,10 @@ private:
 	View2DScene* m_scene;
 	QPoint m_pos;
 	SpecialType m_type;
-	QVector<ColoredValue> m_values;
+	QList<ColoredValue> m_values;
 	QString m_cageLabel;
 	int m_id;
-	qreal m_size;
+	int m_size;
 	int m_range;
 };
 
@@ -79,7 +78,7 @@ CellGraphicsItem::CellGraphicsItem(QPoint pos, int id, View2DScene* scene) {
 	m_range = scene->maxValue();
 }
 
-void CellGraphicsItem::resize(qreal gridSize) {
+void CellGraphicsItem::resize(int gridSize) {
 	m_size = gridSize * 2;
 	
 	setPos(m_pos.x()*m_size, m_pos.y()*m_size);
@@ -116,7 +115,7 @@ void CellGraphicsItem::setType(SpecialType type) {
 	updatePixmap();
 }
 
-void CellGraphicsItem::setValues(const QVector<ColoredValue> &values) {
+void CellGraphicsItem::setValues(const QList<ColoredValue> &values) {
 	m_values = values;
 	
 	updatePixmap();
@@ -161,7 +160,7 @@ void CellGraphicsItem::updatePixmap() {
 
 
 struct GroupGraphicItemSegment {
-	QPointF pos;
+	QPoint pos;
 	int shape;
 	QGraphicsPixmapItem* standard;
 	QGraphicsPixmapItem* highlighted;
@@ -169,11 +168,11 @@ struct GroupGraphicItemSegment {
 
 class GroupGraphicsItem : public QGraphicsItemGroup {
 public:
-	GroupGraphicsItem(const QVector<QPoint> &cells, bool isCage = false);
+	GroupGraphicsItem(const QList<QPoint> &cells, bool isCage = false);
 	~GroupGraphicsItem() override;
 	void hideBlockBorder (bool visible);
 public:
-	void resize(qreal gridSize, bool highlight);
+	void resize(int gridSize, bool highlight);
 	void setHighlight(bool highlight);
 	void setHighlight(const QPoint& pos, bool highlight);
 private:
@@ -183,14 +182,14 @@ private:
 	void createSegment(const QPoint& pos, int shape);
 private:
 	GroupTypes m_type;
-	QVector<QPoint> m_cells;
-	QVector<GroupGraphicItemSegment> m_segments;
+	QList<QPoint> m_cells;
+	QList<GroupGraphicItemSegment> m_segments;
 	bool m_isCage;	// Is the group a cage, as in Killer Sudoku or Mathdoku?
 	bool m_borderVisible;
 };
 
 
-GroupGraphicsItem::GroupGraphicsItem(const QVector<QPoint> &cells, bool isCage) {
+GroupGraphicsItem::GroupGraphicsItem(const QList<QPoint> &cells, bool isCage) {
 	m_cells = cells;
 	m_isCage = isCage;
 	m_borderVisible = true;
@@ -210,7 +209,7 @@ GroupGraphicsItem::GroupGraphicsItem(const QVector<QPoint> &cells, bool isCage)
 }
 
 GroupGraphicsItem::~GroupGraphicsItem() {
-	QVector<GroupGraphicItemSegment>::iterator segment;
+	QList<GroupGraphicItemSegment>::iterator segment;
 	for(segment = m_segments.begin(); segment != m_segments.end(); ++segment) {
 		if(segment->highlighted) delete segment->highlighted;
 		if(segment->standard) delete segment->standard;
@@ -329,7 +328,7 @@ int GroupGraphicsItem::border(int tl, int tr, int bl, int br, int given) {
 void GroupGraphicsItem::setHighlight(bool highlight) {
     if(((m_type & GroupHighlight) == GroupHighlight) == highlight) return;
 
-    QVector<GroupGraphicItemSegment>::iterator segment;
+    QList<GroupGraphicItemSegment>::iterator segment;
     for(segment = m_segments.begin(); segment != m_segments.end(); ++segment) {
 	if (segment->highlighted) {
 	    segment->highlighted->setVisible(highlight);
@@ -354,8 +353,8 @@ void GroupGraphicsItem::setHighlight(const QPoint& pos, bool highlight) {
 	setHighlight(m_cells.contains(pos) && highlight);
 }
 
-void GroupGraphicsItem::resize(qreal gridSize, bool highlight) {
-	qreal size = gridSize*2;
+void GroupGraphicsItem::resize(int gridSize, bool highlight) {
+	int size = gridSize*2;
 	Renderer* r = Renderer::instance();
 
 	highlight = (m_type == GroupCage); // IDW test.
@@ -363,7 +362,7 @@ void GroupGraphicsItem::resize(qreal gridSize, bool highlight) {
 	GroupTypes standard = m_type & GroupUnhighlightedMask;
 	GroupTypes highlighted = m_type | GroupHighlight;
 	
-	QVector<GroupGraphicItemSegment>::iterator segment;
+	QList<GroupGraphicItemSegment>::iterator segment;
 	for(segment = m_segments.begin(); segment != m_segments.end(); ++segment) {
 		QPointF pos = segment->pos*gridSize;
 		// Has standard pixmap item?
@@ -395,13 +394,13 @@ View2DScene::~View2DScene() {
 	delete m_cursor; // needs to be deleted before cells
 
 	// groups need to be deleted before m_groupLayer
-	QVector<GroupGraphicsItem*>::iterator group;	
+	QList<GroupGraphicsItem*>::iterator group;
 	for(group = m_groups.begin(); group != m_groups.end(); ++group) {
 		delete *group;
 	}
 	
 	// cells need to be deleted before m_cellLayer
-	QVector<CellGraphicsItem*>::iterator cell;
+	QList<CellGraphicsItem*>::iterator cell;
 	for(cell = m_cells.begin(); cell != m_cells.end(); ++cell) {
 		delete *cell;
 	}
@@ -448,9 +447,9 @@ void View2DScene::init(const Game& game) {
 		else
 			m_cells[i]->setType(SpecialCell);
 		if(game.value(i))
-			m_cells[i]->setValues(QVector<ColoredValue>() << ColoredValue(game.value(i),0));
+			m_cells[i]->setValues(QList<ColoredValue>() << ColoredValue(game.value(i),0));
 		else
-			m_cells[i]->setValues(QVector<ColoredValue>());
+			m_cells[i]->setValues(QList<ColoredValue>());
 		if(m_cursorPos < 0) m_cursorPos = i;
 	}
 
@@ -460,8 +459,8 @@ void View2DScene::init(const Game& game) {
 	bool hasBothBlocksAndCages = (g->specificType() == KillerSudoku);
 	for(int i = 0; i < g->cliqueCount(); ++i) {
 		// Set the shape of each group.
-		QVector<int> idx = g->clique(i);
-		QVector<QPoint> pts = QVector<QPoint>(idx.size());
+		QList<int> idx = g->clique(i);
+		QList<QPoint> pts = QList<QPoint>(idx.size());
 		for(int j = 0; j < idx.size(); ++j) {
 		    pts[j] = QPoint(g->cellPosX(idx[j]), g->cellPosY(idx[j]));
 		}
@@ -497,8 +496,8 @@ void View2DScene::initCageGroup (int cageNum, bool drawLabel) {
 	// Set the graphical shape and look of a Mathdoku or KillerSudoku cage.
 	SKGraph* g = m_game.puzzle()->graph();
 	int offset = g->cliqueCount();
-	QVector<int> idx = g->cage(cageNum);
-	QVector<QPoint> pts = QVector<QPoint>(idx.size());
+	QList<int> idx = g->cage(cageNum);
+	QList<QPoint> pts = QList<QPoint>(idx.size());
 	for(int j = 0; j < idx.size(); ++j) {
 	    pts[j] = QPoint(g->cellPosX(idx[j]), g->cellPosY(idx[j]));
 	}
@@ -528,12 +527,11 @@ void View2DScene::setSceneSize(const QSize& size) {
 	SKGraph* g = m_game.puzzle()->graph();
 	setSceneRect(QRectF(0, 0, size.width(), size.height()));
 	
-	const qreal dpr = qApp->devicePixelRatio();
-	qreal width = size.width() * dpr / (g->sizeX()+1);
-	qreal height = size.height() * dpr / (g->sizeY()+1);
-	qreal grid = qRound(qMin(width, height)) / 2 / dpr;
-	qreal offsetX = size.width()/2 - g->sizeX()*grid;
-	qreal offsetY = size.height()/2 - g->sizeY()*grid;
+	int width = size.width() / (g->sizeX()+1);
+	int height = size.height() / (g->sizeY()+1);
+	int grid = qMin(width, height) / 2;
+	int offsetX = size.width()/2 - g->sizeX()*grid;
+	int offsetY = size.height()/2 - g->sizeY()*grid;
 
 	m_groupLayer->setPos(offsetX, offsetY);
 	m_cellLayer->setPos(offsetX, offsetY);
@@ -598,7 +596,7 @@ void View2DScene::update(int cell) {
 		if(m_cells[cell] == nullptr) return;
 		CellInfo cellInfo = m_game.cellInfo(cell);
 
-		QVector<ColoredValue> values;
+		QList<ColoredValue> values;
 		switch(cellInfo.state()) {
 			case GivenValue:
 				// TODO - Implement allCellsLookSame preference.
